@@ -124,9 +124,23 @@
 #'               In addition, `TRUE` and `FALSE` are allowed as alternatives to  `"always"` and `"no"`.
 #'               see details. 
 #'               
-#' @param  lpPackage When non-NULL, intervals by \code{\link{ComputeIntervals}} 
+#' @param  lpPackage 
+#'  * **`lpPackage`:**
+#'                   When non-NULL, intervals by \code{\link{ComputeIntervals}} 
 #'                   will be included in the output.
 #'                   See its documentation for valid parameter values for 'lpPackage'.
+#'                   If, additionally, at least one of the two \code{\link{RangeLimitsDefault}} parameters below is specified, 
+#'                   further suppression will be performed to satisfy the interval width requirements.
+#'        Then, the values in the output variable `suppressed_integer` means: 
+#'                   no suppression (0), 
+#'                   primary suppression (1), 
+#'                   secondary suppression (2), 
+#'                   additional suppression applied by an interval algorithm limited to linearly independent cells (3), 
+#'                   and further suppression according to the final gauss algorithm (4).
+#'        Intervals, `[lo_1, up_1]`, are intervals calculated prior to additional suppression.         
+#'    * **`rangePercent`:** Required interval width expressed as a percentage
+#'    * **`rangeMin`:** Minimum required width of the interval
+#'    
 #'                   Please note that interval calculations may have a 
 #'                   different interface in future versions.
 #'                                 
@@ -252,7 +266,14 @@ GaussSuppressionFromData = function(data, dimVar = NULL, freqVar=NULL,
       if (!require(lpPackage, character.only = TRUE, quietly = TRUE)) {
         stop(paste0("Package '", lpPackage, "' is not available."))
       }
-      OutputFunction <- OutputIntervals
+      if (hasArg(rangePercent) | hasArg(rangeMin)) {
+        # if (!(hasArg(rangePercent) & hasArg(rangeMin))) {
+        #   stop("Both rangePercent and rangeMin must be specified, not just one of them.")
+        # }
+        OutputFunction <- OutputFixRiskyIntervals
+      } else {
+        OutputFunction <- OutputIntervals
+      }
     } else {
       OutputFunction <- NULL
     }
