@@ -1,9 +1,10 @@
 
 
-#' Suppress volume tables using dominant cell primary suppression.
+#' Suppress magnitude tables using dominance `(n,k)` or p% rule for primary suppression.
 #'
 #' @inheritParams GaussSuppressionFromData
-#' @inheritParams DominanceRule
+#' @inheritParams MagnitudeRule
+#' @param n Parameter `n` in dominance rule. Default is `1:length(k)`.
 #' @param dominanceVar Numerical variable to be used in dominance rule. 
 #'           The first `numVar` variable will be used if it is not specified.
 #' @param numVar Numerical variable to be aggregated.
@@ -45,6 +46,8 @@
 #' 
 #' # basic use
 #' SuppressDominantCells(d, n = c(1,2), k = c(80,70), numVar = "num", formula = ~v1 -1)
+#' SuppressDominantCells(d, k = c(80,70), numVar = "num", formula = ~v1 -1) # same as above
+#' SuppressDominantCells(d, pPercent = 7, numVar = "num", formula = ~v1 -1) 
 #' 
 #' # with weights
 #' SuppressDominantCells(d, n = c(1,2), k = c(80,70), numVar = "num",
@@ -80,8 +83,9 @@
 #' SuppressDominantCells(data = d2, n = c(1, 2), k = c(70, 95), numVar = "v", 
 #'                       hierarchies = list(main_income = ml, k_group = "Total_Norway"))
 SuppressDominantCells <- function(data,
-                                  n,
-                                  k,
+                                  n = 1:length(k),
+                                  k = NULL,
+                                  pPercent = NULL, 
                                   allDominance = FALSE,
                                   dominanceVar = NULL,
                                   numVar = NULL,
@@ -95,7 +99,9 @@ SuppressDominantCells <- function(data,
                                   singletonZeros = FALSE,
                                   spec = PackageSpecs("dominanceSpec")
                                   ) {
-  
+  if (is.null(k)) {
+    n <- NULL
+  }
   if (length(dominanceVar)) {
     numVar <- unique(c(numVar, dominanceVar))
   }
@@ -140,6 +146,7 @@ SuppressDominantCells <- function(data,
     data = data,
     n = n,
     k = k,
+    pPercent =  pPercent,
     allDominance = allDominance,
     dominanceVar = dominanceVar, 
     numVar = numVar,
